@@ -4,8 +4,8 @@ __author__ = ('Francesco Beghini (francesco.beghini@unitn.it),'
               'Duy Tin Truong, '
               'Francesco Asnicar (f.asnicar@unitn.it), '
               'Aitor Blanco Miguez (aitor.blancomiguez@unitn.it)')
-__version__ = '3.0.13'
-__date__ = '27 Jul 2021'
+__version__ = '3.0.14'
+__date__ = '19 Jan 2022'
 
 import sys
 try:
